@@ -329,7 +329,7 @@ class SIAService(DALService):
 
 class SIAQuery(DALQuery):
     """
-    a class for preparing an query to an SIA service.  Query constraints
+    a class for preparing a query to an SIA service.  Query constraints
     are added via its service type-specific methods.  The various execute()
     functions will submit the query and return the results.
 
@@ -915,7 +915,7 @@ class SIARecord(SodaRecordMixin, DatalinkRecordMixin, Record):
             out = re.sub(r'\s+', '_', out.strip())
         return out
 
-    def suggest_extension(self, default=None):
+    def suggest_extension(self, default='dat'):
         """
         returns a recommended filename extension for the dataset described
         by this record.  Typically, this would look at the column describing
