@@ -786,3 +786,15 @@ class TestTAPCapabilities:
     def test_get_udf(self, tapservice):
         func = tapservice.get_tap_capability().get_adql().get_udf("IVO_hasword")  # case insensitive!
         assert func.form == "ivo_hasword(haystack TEXT, needle TEXT) -> INTEGER"
+
+
+def test_get_endpoint_candidates():
+    # Directly instantiate the TAPService with a known base URL
+    svc = TAPService("http://astroweb.projects.phys.ucl.ac.uk:8000/tap")
+
+    # Check if the correct endpoint candidates are generated
+    expected_urls = [
+        "http://astroweb.projects.phys.ucl.ac.uk:8000/tap/capabilities",
+        "http://astroweb.projects.phys.ucl.ac.uk:8000/capabilities"
+    ]
+    assert svc._get_endpoint_candidates("capabilities") == expected_urls
