@@ -397,7 +397,7 @@ class Interface:
         return (f"Interface({self.access_url!r}, standard_id={self.standard_id!r},"
                 f" intf_type={self.type!r}, intf_role={self.role!r})")
 
-    def to_service(self):
+    def to_service(self, *, session=None):
         if self.type == "vr:webbrowser":
             return _BrowserService(self.access_url)
 
@@ -412,9 +412,9 @@ class Interface:
                              f" standard id {self.standard_id}.")
 
         if service_class == sia2.SIA2Service:
-            return service_class(self.access_url, check_baseurl=False)
+            return service_class(self.access_url, check_baseurl=False, session=session)
         else:
-            return service_class(self.access_url)
+            return service_class(self.access_url, session=session)
 
     def supports(self, standard_id):
         """returns true if we believe the interface should be able to talk
@@ -768,7 +768,8 @@ class RegistryResource(dalq.Record):
 
     def get_service(self,
                     service_type: str = None,
-                    lax: bool = True):
+                    lax: bool = True,
+                    session: object = None):
         """
         return an appropriate DALService subclass for this resource that
         can be used to search the resource using service_type.
@@ -803,6 +804,10 @@ class RegistryResource(dalq.Record):
             function choose the first matching capability by default
             Pass lax=False to instead raise a DALQueryError.
 
+        session : object
+            optional requests session to use to communicate with the service
+            constructed.
+
         Returns
         -------
         `pyvo.dal.DALService`
@@ -813,7 +818,7 @@ class RegistryResource(dalq.Record):
             opening a web browser on the access URL.
         """
         return self.get_interface(service_type, lax, std_only=True
-                                  ).to_service()
+                                  ).to_service(session=session)
 
     @property
     def service(self):
@@ -843,15 +848,16 @@ class RegistryResource(dalq.Record):
         the DAL service type would expect.  See the documentation for the
         appropriate service type:
 
-        ============  =========================================
+        ============  ===========================================
         Service type  Use the argument syntax for
-        ============  =========================================
+        ============  ===========================================
         catalog       :py:meth:`pyvo.dal.scs.SCSService.search`
-        image         :py:meth:`pyvo.dal.sia.SIAService.search`
-        spectrum      :py:meth:`pyvo.dal.ssa.SSAService.search`
+        sia           :py:meth:`pyvo.dal.sia.SIAService.search`
+        sia2          :py:meth:`pyvo.dal.sia2.SIA2Service.search`
+        ssa           :py:meth:`pyvo.dal.ssa.SSAService.search`
         line          :py:meth:`pyvo.dal.sla.SLAService.search`
         database      *not yet supported*
-        ============  =========================================
+        ============  ===========================================
 
         Raises
         ------
@@ -995,6 +1001,7 @@ class RegistryResource(dalq.Record):
         res.name = table_row["table_name"]
         res.title = table_row["table_title"]
         res.description = table_row["table_description"]
+        res.utype = table_row["table_utype"]
         res._columns = [
             self._build_vosi_column(row)
             for row in columns]
@@ -1022,7 +1029,8 @@ class RegistryResource(dalq.Record):
         svc = get_RegTAP_service()
 
         tables = svc.run_sync(
-            """SELECT table_name, table_description, table_index, table_title
+            """SELECT table_name, table_description, table_index, table_title,
+                table_utype
             FROM rr.res_table
             WHERE ivoid={}""".format(
                 rtcons.make_sql_literal(self.ivoid)))
