@@ -34,6 +34,7 @@ SERVICE_TYPE_MAP = dict((k, "ivo://ivoa.net/std/" + v)
                         for k, v in [
     ("image", "sia"),
     ("sia", "sia"),
+    ("sia1", "sia"),
     # SIA2 is irregular
     # funky scheme used by SIA2 without breaking everything else
     ("spectrum", "ssa"),
@@ -207,7 +208,7 @@ class Constraint:
 
 class Freetext(Constraint):
     """
-    A contraint using plain text to match against title, description,
+    A constraint using plain text to match against title, description,
     subjects, and person names.
     """
     _keyword = "keywords"
@@ -217,11 +218,17 @@ class Freetext(Constraint):
 
         Parameters
         ----------
-        *words : tuple of str
+        *words : str
+            One or more string arguments.
             It is recommended to pass multiple words in multiple strings
             arguments.  You can pass in phrases (i.e., multiple words
             separated by space), but behaviour might then vary quite
             significantly between different registries.
+
+        Examples
+        --------
+        >>> from pyvo import registry
+        >>> registry.Freetext("Gamma", "Ray", "Burst") # doctest: +IGNORE_OUTPUT
         """
         self.words = words
 
@@ -316,9 +323,9 @@ class Servicetype(Constraint):
 
     The constraint normally is a custom keyword, one of:
 
-    * ``image`` (image services; at this point equivalent to sia, but
-      scheduled to include sia2, too)
-    * ``sia`` (SIAP version 1 services)
+
+    * ``sia``, ``sia1`` (SIAP version 1 services; prefer ``sia1`` for symmetry,
+      although ``sia`` will be kept as the official IVOA short name for SIA1)
     * ``sia2`` (SIAP version 2 services)
     * ``spectrum``, ``ssa``, ``ssap`` (all synonymous for spectral
       services, prefer ``spectrum``)
@@ -326,6 +333,8 @@ class Servicetype(Constraint):
       ``scs``)
     * ``line`` (for SLAP services)
     * ``tap``, ``table`` (synonymous for TAP services, prefer ``tap``)
+    * ``image`` (a to be deprecated alias for sia1)
+    * ``spectrum`` (a to be deprecated alias for ssap)
 
     You can also pass in the standards' ivoid (which
     generally looks like
@@ -353,7 +362,7 @@ class Servicetype(Constraint):
 
         Parameters
         ----------
-        *stds : tuple of str
+        *stds : str
             one or more standards identifiers.  The constraint will
             match records that have any of them.
         """
@@ -428,7 +437,7 @@ class Waveband(Constraint):
 
         Parameters
         ----------
-        *bands : tuple of strings
+        *bands : strings
             One or more of the terms given in http://www.ivoa.net/rdf/messenger.
             The constraint matches when a resource declares at least
             one of the messengers listed.
@@ -525,6 +534,7 @@ class Ivoid(Constraint):
         ----------
 
         ivoid : string
+            One or more string arguments.
             The IVOA identifier of the resource to match.  As RegTAP
             requires lowercasing ivoids on ingestion, the constraint
             lowercases the ivoid passed in, too.
@@ -546,7 +556,7 @@ class UCD(Constraint):
         Parameters
         ----------
 
-        patterns : tuple of strings
+        patterns : strings
             SQL patterns (i.e., ``%`` is 0 or more characters) for
             UCDs.  The constraint will match when a resource has
             at least one column matching one of the patterns.
@@ -605,6 +615,10 @@ class Spatial(Constraint):
     are interpreted in degrees)::
 
         >>> resources = registry.Spatial((SkyCoord("23d +3d"), 3))
+
+    Or you can provide the radius angle as an Astropy Quantity:
+
+        >>> resources = registry.Spatial((SkyCoord("23d +3d"), 1*u.rad))
     """
     _keyword = "spatial"
     _extra_tables = ["rr.stc_spatial"]
@@ -621,7 +635,7 @@ class Spatial(Constraint):
             as a DALI point, a 3-sequence as a DALI circle, a 2n sequence
             as a DALI polygon.  Additionally, strings are interpreted
             as ASCII MOCs, SkyCoords as points, and a pair of a
-            SkyCoord and a float as a circle.  Other types (proper
+            SkyCoord and a float or Quantity as a circle.  Other types (proper
             geometries or MOCPy objects) might be supported in the
             future.
         order : int, optional
@@ -651,9 +665,16 @@ class Spatial(Constraint):
 
         elif len(geom_spec) == 2:
             if isinstance(geom_spec[0], SkyCoord):
+                # If radius given is astropy quantity, then convert to degrees
+                if isinstance(geom_spec[1], u.Quantity):
+                    if geom_spec[1].unit.physical_type != 'angle':
+                        raise ValueError("Radius quantity is not of type angle.")
+                    radius = geom_spec[1].to(u.deg).value
+                else:
+                    radius = geom_spec[1]
                 geom = tomoc(format_function_call("CIRCLE",
                                                   [geom_spec[0].ra.value, geom_spec[0].dec.value,
-                                                   geom_spec[1]]))
+                                                   radius]))
             else:
                 geom = tomoc(format_function_call("POINT", geom_spec))
 
@@ -908,8 +929,7 @@ def build_regtap_query(constraints, service):
             "(" + constraint.get_search_condition(service) + ")")
         extra_tables |= set(constraint._extra_tables)
 
-    joined_tables = ["rr.resource", "rr.capability", "rr.interface",
-                     "rr.alt_identifier"
+    joined_tables = ["rr.resource", "rr.capability", "rr.interface"
                      ] + list(extra_tables)
 
     # see comment in regtap.RegistryResource for the following
