@@ -128,7 +128,7 @@ class TestServicetypeConstraint:
                 " 'ivo://ivoa.net/std/sia')")
 
     def test_includeaux(self):
-        assert (rtcons.Servicetype("http://extstandards/invention", "image"
+        assert (rtcons.Servicetype("http://extstandards/invention", "sia1"
                                    ).include_auxiliary_services().get_search_condition(FAKE_GAVO)
                 == "standard_id IN ('http://extstandards/invention',"
                 " 'http://extstandards/invention#aux',"
@@ -140,7 +140,7 @@ class TestServicetypeConstraint:
             rtcons.Servicetype("junk")
         assert str(excinfo.value) == ("Service type junk is neither"
                                       " a full standard URI nor one of the bespoke identifiers"
-                                      " image, sia, spectrum, ssap, ssa, scs, conesearch, line, slap,"
+                                      " image, sia, sia1, spectrum, ssap, ssa, scs, conesearch, line, slap,"
                                       " table, tap, sia2")
 
     def test_legacy_term(self):
@@ -253,6 +253,15 @@ class TestSpatialConstraint:
         assert cons.get_search_condition(FAKE_GAVO) == "1 = CONTAINS(MOC(6, CIRCLE(3.0, -30.0, 3)), coverage)"
         assert cons._extra_tables == ["rr.stc_spatial"]
 
+    def test_SkyCoord_Circle_RadiusQuantity(self):
+        for radius in [3*u.deg, 180*u.Unit('arcmin'), 10800*u.Unit('arcsec')]:
+            cons = registry.Spatial((SkyCoord(3 * u.deg, -30 * u.deg), radius))
+            assert cons.get_search_condition(FAKE_GAVO) == (
+                "1 = CONTAINS(MOC(6, CIRCLE(3.0, -30.0, 3.0)), coverage)")
+
+        with pytest.raises(ValueError, match="is not of type angle."):
+            cons = registry.Spatial((SkyCoord(3 * u.deg, -30 * u.deg), (1 * u.m)))
+
     def test_enclosed(self):
         cons = registry.Spatial("0/1-3", intersect="enclosed")
         assert cons.get_search_condition(FAKE_GAVO) == "1 = CONTAINS(coverage, MOC('0/1-3'))"
